#!/usr/bin/env python3
import logging
import uuid

from django.core.management.base import BaseCommand

from arkindex.dataimport.models import Repository, RepositoryType, Revision, Worker, WorkerVersion
from arkindex_common.ml_tool import MLToolType

logging.basicConfig(
    level=logging.INFO,
    format='[%(levelname)s] %(message)s',
)
logger = logging.getLogger(__name__)


class Command(BaseCommand):
    help = 'Create a fake worker version'

    def add_arguments(self, parser):
        parser.add_argument(
            "--url",
            help="URL of the repository",
            required=True
        )
        parser.add_argument(
            "--name",
            help="Name of the worker",
            required=True
        )
        parser.add_argument(
            "--slug",
            help="Slug of the worker",
            required=True
        )

    def handle(self, url, name, slug, *args, **options):
        versions = WorkerVersion.objects.filter(worker__slug=slug)
        if versions.exists():
            versions_id = list(versions.values_list('id', flat=True).distinct())
            logger.info(f"This worker already has versions: {versions_id}")
            return

        repo, _ = Repository.objects.get_or_create(
            url=url,
            type=RepositoryType.Worker,
        )

        worker, _ = Worker.objects.get_or_create(
            name=name,
            slug=slug,
            type=MLToolType.Classifier,
            repository=repo
        )

        revision = Revision.objects.create(
            repo_id=repo.id,
            hash=uuid.uuid4().hex,
            message="Fake revision",
            author="Teklia Bot"
        )

        version = WorkerVersion.objects.create(
            worker=worker,
            revision=revision,
            configuration="",
        )

        logger.info(f"Created a worker version: {version.id}")
