from django.core.management import call_command

from arkindex.dataimport.models import Repository, RepositoryType, Revision, Worker, WorkerVersion, WorkerVersionState
from arkindex.project.tests import FixtureTestCase
from arkindex_common.ml_tool import MLToolType


class TestFakeWorker(FixtureTestCase):

    def test_create_version(self):
        slug = 'myslug'
        name = 'My name'
        url = 'http://fake'

        self.assertFalse(WorkerVersion.objects.filter(worker__slug=slug).exists())

        call_command(
            'fake_worker_version',
            slug=slug,
            name=name,
            url=url,
        )

        worker = Worker.objects.get(slug=slug)
        version = WorkerVersion.objects.get(worker__slug=slug)
        repo = worker.repository
        revision = Revision.objects.get(repo_id=repo.id)

        self.assertEqual(repo.url, url)
        self.assertEqual(repo.type, RepositoryType.Worker)

        self.assertEqual(worker.name, name)
        self.assertEqual(worker.slug, slug)
        self.assertEqual(worker.type, MLToolType.Classifier)

        self.assertIsNotNone(revision.hash)
        self.assertEqual(revision.message, "Fake revision")
        self.assertEqual(revision.author, "Teklia Bot")

        self.assertEqual(version.worker, worker)
        self.assertEqual(version.revision, revision)
        self.assertEqual(version.state, WorkerVersionState.Created)

    def test_version_already_exists(self):
        slug = 'myslug'
        name = 'My name'
        url = 'http://fake'
        call_command(
            'fake_worker_version',
            slug=slug,
            name=name,
            url=url,
        )

        old_versions = WorkerVersion.objects.filter(worker__slug=slug)
        old_versions_id = list(old_versions.values_list('id', flat=True).distinct())
        self.assertTrue(old_versions.exists())

        call_command(
            'fake_worker_version',
            slug=slug,
            name=name,
            url=url,
        )

        new_versions = WorkerVersion.objects.filter(worker__slug=slug)
        new_versions_id = list(new_versions.values_list('id', flat=True).distinct())
        self.assertEqual(old_versions_id, new_versions_id)

    def test_repository_already_exists(self):
        slug = 'myslug'
        name = 'My name'
        url = 'http://fake'

        repo = Repository.objects.create(
            url=url,
            type=RepositoryType.Worker,
        )

        call_command(
            'fake_worker_version',
            slug=slug,
            name=name,
            url=url,
        )

        version = WorkerVersion.objects.get(worker__slug=slug)
        self.assertEqual(version.worker.repository.id, repo.id)

    def test_worker_already_exists(self):
        slug = 'myslug'
        name = 'My name'
        url = 'http://fake'

        repo = Repository.objects.create(
            url=url,
            type=RepositoryType.Worker,
        )

        worker = Worker.objects.create(
            name=name,
            slug=slug,
            type=MLToolType.Classifier,
            repository=repo
        )

        call_command(
            'fake_worker_version',
            slug=slug,
            name=name,
            url=url,
        )

        version = WorkerVersion.objects.get(worker__slug=slug)
        self.assertEqual(version.worker.repository.id, repo.id)
        self.assertEqual(version.worker.id, worker.id)
