#!/usr/bin/env python3
import logging
import uuid

from django.core.management.base import BaseCommand

from arkindex.documents.models import Element
from arkindex_common.tools import Timer

# Enable deletion signal logs
logging.basicConfig(
    level=logging.INFO,
    format='[%(levelname)s] %(message)s',
)


def valid_uuid(value):
    try:
        return uuid.UUID(value)
    except ValueError:
        raise Exception(f"Not an UUID: {value}")


class Command(BaseCommand):
    help = 'Delete an element and its children'

    def add_arguments(self, parser):
        super().add_arguments(parser)
        parser.add_argument(
            'element_id',
            help='ID of the top element to delete (multiple supported)',
            type=valid_uuid,
            nargs='+',
        )

    def handle(self, element_id, verbosity=0, **options):
        for element in Element.objects.filter(id__in=element_id):
            self.stdout.write(f"Deleting {element.id} : {element}")
            with Timer() as t:
                element.delete()
            self.stdout.write(f'Deleted {element} in {t.delta}')
